@@ -1,6 +1,6 @@
 /* qprogram-starter, a program to start programs or commands, with
    the option to log output and errors and to shutdown the system.
- * Copyright (C) 2010-2011 Christian Metscher <hakaishi@web.de>
+ * Copyright (C) 2010-2013 Christian Metscher <hakaishi@web.de>
 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -15,26 +15,28 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
+
 #ifndef GUI_H
 #define GUI_H
 
 #include "ui_gui.h"
 #include <QFileDialog>
 #include <QtGlobal>
-#include <QSettings>
 #include <QProcess>
 #include <QTextStream>
 
+class Preferences;
 
-class Gui : public QWidget, public Ui::Gui {
+class Gui : public QMainWindow, public Ui::Gui {
      Q_OBJECT // important for creating own singals and slots
  
      public:
-      Gui(QWidget *parent = 0);
+      Gui();
       ~Gui();
       void loadSettings();
 
      private:
+      Preferences    *pref;
       QTimer         *dateTimeTimer, *timer;
       QProcess       *process1, *process2;
       QDateTime      nextDate, timeInTheFuture;
@@ -43,7 +45,6 @@ class Gui : public QWidget, public Ui::Gui {
       QString        shell, file, errProcess1, errProcess2,
                      outputProcess1, outputProcess2;
       QStringList    processArgs1, processArgs2;
-      QSettings      *settings; 
       QString        program1, program2;
       bool           process2Started;
       bool           aborted;
@@ -65,6 +66,7 @@ class Gui : public QWidget, public Ui::Gui {
       void shutdown_or_message(); //either shuts down the system or shows if the process is finished
       void info_hint();   //shows a InfoMessageBox
       void saveData();
+      void saveSettings();
       void showLogs();
 
      signals:
