@@ -14,6 +14,15 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
+
+/* INFO: For Windows hibernate has to be activated:
+   Please note that this only works if the hardware supports it and
+   enough RAM is available.
+   - powercfg -a #prints aviable sleep states
+   - powercfg -hibernate on
+   - powercfg -hibernate off
+*/
+
 #ifndef POWER_H
 #define POWER_H
 
@@ -25,11 +34,11 @@
 #include <QTextStream>
 
 extern bool verbose;
+extern QString shell;
 
 namespace Power{
 
 QTextStream oput(stdout);
-QString shell = QProcess::systemEnvironment().filter("SHELL").first().remove("SHELL=");
 
 bool lockMyScreen;
 bool automatic = false;
@@ -129,6 +138,7 @@ void shutdown(){
            oput << "W: " << response.errorName() << ": "
                 << response.errorMessage() << endl;
          QProcess::startDetached("sudo shutdown -P now");
+         QProcess::startDetached("sudo shutdown -h -P now");
        }
      }
   }
@@ -180,10 +190,13 @@ void shutdown(){
               << response.errorMessage() << endl;
     }
   }
-  if(sudo)
-    QProcess::startDetached("sudo shutdown -P now");
+  if(sudo){
+     QProcess::startDetached("sudo shutdown -P now");
+     QProcess::startDetached("sudo shutdown -h -P now");
+  }
   if(user)
-    QProcess::startDetached(shell, args);
+    if(!shell.isEmpty())
+      QProcess::startDetached(shell, args);
 
   //resetting variables
   automatic = false;
@@ -318,7 +331,8 @@ void reboot(){
   if(sudo)
     QProcess::startDetached("sudo shutdown -r now");
   if(user)
-    QProcess::startDetached(shell, args);
+    if(!shell.isEmpty())
+      QProcess::startDetached(shell, args);
 
   //resetting variables
   automatic = false;
@@ -400,7 +414,8 @@ void suspend(){
 
   if(automatic){
    #ifdef Q_OS_WIN32
-     QProcess::startDetached("rundll32 powrprof.dll,SetSuspendState"); // Windows command to suspend immediately
+     QProcess::startDetached("powercfg -hibernate off"); // enable suspend
+     QProcess::startDetached("rundll32 powrprof.dll,SetSuspendState");
      }
    #else
      g_pwr1 = QProcess::startDetached("gnome-power-cmd.sh suspend");
@@ -474,7 +489,9 @@ void suspend(){
     }
   }
   if(user)
-    QProcess::startDetached(shell, args);
+    if(!shell.isEmpty())
+      QProcess::startDetached(shell, args);
+
 
   //resetting variables
   automatic = false;
@@ -555,7 +572,8 @@ void hibernate(){
 
   if(automatic){
    #ifdef Q_OS_WIN32
-     QProcess::startDetached("rundll32 powrprof.dll,SetSuspendState"); // Windows command to hibernate immediately
+     QProcess::startDetached("powercfg -hibernate on"); // enable hibernate
+     QProcess::startDetached("rundll32 powrprof.dll,SetSuspendState");
      }
    #else
      g_pwr1 = QProcess::startDetached("gnome-power-cmd.sh hibernate");
@@ -627,7 +645,8 @@ void hibernate(){
     }
   }
   if(user)
-    QProcess::startDetached(shell, args);
+    if(!shell.isEmpty())
+      QProcess::startDetached(shell, args);
 
   //resetting variables
   automatic = false;
